summaryrefslogtreecommitdiffstats
path: root/src/gui/studio
diff options
context:
space:
mode:
Diffstat (limited to 'src/gui/studio')
-rw-r--r--src/gui/studio/AudioMixerWindow.cpp142
-rw-r--r--src/gui/studio/AudioMixerWindow.h3
-rw-r--r--src/gui/studio/AudioPlugin.cpp2
-rw-r--r--src/gui/studio/AudioPluginManager.h2
-rw-r--r--src/gui/studio/AudioPluginOSCGUI.cpp2
-rw-r--r--src/gui/studio/AudioPluginOSCGUIManager.cpp24
-rw-r--r--src/gui/studio/BankEditorDialog.cpp54
-rw-r--r--src/gui/studio/BankEditorDialog.h3
-rw-r--r--src/gui/studio/ChangeRecordDeviceCommand.cpp4
-rw-r--r--src/gui/studio/DeviceEditorDialog.cpp8
-rw-r--r--src/gui/studio/DeviceEditorDialog.h3
-rw-r--r--src/gui/studio/DeviceManagerDialog.cpp42
-rw-r--r--src/gui/studio/DeviceManagerDialog.h3
-rw-r--r--src/gui/studio/MidiBankListViewItem.cpp6
-rw-r--r--src/gui/studio/MidiBankListViewItem.h2
-rw-r--r--src/gui/studio/MidiDeviceListViewItem.cpp14
-rw-r--r--src/gui/studio/MidiDeviceListViewItem.h6
-rw-r--r--src/gui/studio/MidiKeyMapListViewItem.cpp4
-rw-r--r--src/gui/studio/MidiKeyMapListViewItem.h2
-rw-r--r--src/gui/studio/MidiKeyMappingEditor.cpp8
-rw-r--r--src/gui/studio/MidiKeyMappingEditor.h5
-rw-r--r--src/gui/studio/MidiMixerVUMeter.cpp6
-rw-r--r--src/gui/studio/MidiMixerVUMeter.h2
-rw-r--r--src/gui/studio/MidiMixerWindow.cpp74
-rw-r--r--src/gui/studio/MidiMixerWindow.h3
-rw-r--r--src/gui/studio/MidiProgramsEditor.cpp18
-rw-r--r--src/gui/studio/MidiProgramsEditor.h5
-rw-r--r--src/gui/studio/MixerWindow.cpp4
-rw-r--r--src/gui/studio/MixerWindow.h3
-rw-r--r--src/gui/studio/NameSetEditor.cpp12
-rw-r--r--src/gui/studio/NameSetEditor.h5
-rw-r--r--src/gui/studio/RemapInstrumentDialog.cpp4
-rw-r--r--src/gui/studio/RemapInstrumentDialog.h3
-rw-r--r--src/gui/studio/StudioControl.cpp24
-rw-r--r--src/gui/studio/SynthPluginManagerDialog.cpp34
-rw-r--r--src/gui/studio/SynthPluginManagerDialog.h3
-rw-r--r--src/gui/studio/TimerCallbackAssistant.cpp2
-rw-r--r--src/gui/studio/TimerCallbackAssistant.h3
38 files changed, 278 insertions, 266 deletions
diff --git a/src/gui/studio/AudioMixerWindow.cpp b/src/gui/studio/AudioMixerWindow.cpp
index 2b7ad0e..e95a6b1 100644
--- a/src/gui/studio/AudioMixerWindow.cpp
+++ b/src/gui/studio/AudioMixerWindow.cpp
@@ -89,90 +89,90 @@ static const unsigned int MIXER_SHOW_UNASSIGNED_FADERS = 1 << 3;
static const unsigned int MIXER_OMIT_SYNTH_FADERS = 1 << 4;
-AudioMixerWindow::AudioMixerWindow(TQWidget *parent,
+AudioMixerWindow::AudioMixerWindow(TQWidget *tqparent,
RosegardenGUIDoc *document):
- MixerWindow(parent, document),
+ MixerWindow(tqparent, document),
m_mainBox (0)
{
populate();
- KStdAction::close(this,
+ KStdAction::close(TQT_TQOBJECT(this),
TQT_SLOT(slotClose()),
actionCollection());
- TQIconSet icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ TQIconSet icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-play")));
- KAction *play = new KAction(i18n("&Play"), icon, Key_Enter, this,
+ KAction *play = new KAction(i18n("&Play"), icon, Key_Enter, TQT_TQOBJECT(this),
TQT_SIGNAL(play()), actionCollection(), "play");
// Alternative shortcut for Play
KShortcut playShortcut = play->shortcut();
playShortcut.append( KKey(Key_Return + CTRL) );
play->setShortcut(playShortcut);
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-stop")));
- new KAction(i18n("&Stop"), icon, Key_Insert, this,
+ new KAction(i18n("&Stop"), icon, Key_Insert, TQT_TQOBJECT(this),
TQT_SIGNAL(stop()), actionCollection(), "stop");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-rewind")));
- new KAction(i18n("Re&wind"), icon, Key_End, this,
+ new KAction(i18n("Re&wind"), icon, Key_End, TQT_TQOBJECT(this),
TQT_SIGNAL(rewindPlayback()), actionCollection(),
"playback_pointer_back_bar");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-ffwd")));
- new KAction(i18n("&Fast Forward"), icon, Key_PageDown, this,
+ new KAction(i18n("&Fast Forward"), icon, Key_PageDown, TQT_TQOBJECT(this),
TQT_SIGNAL(fastForwardPlayback()), actionCollection(),
"playback_pointer_forward_bar");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-rewind-end")));
- new KAction(i18n("Rewind to &Beginning"), icon, 0, this,
+ new KAction(i18n("Rewind to &Beginning"), icon, 0, TQT_TQOBJECT(this),
TQT_SIGNAL(rewindPlaybackToBeginning()), actionCollection(),
"playback_pointer_start");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-ffwd-end")));
- new KAction(i18n("Fast Forward to &End"), icon, 0, this,
+ new KAction(i18n("Fast Forward to &End"), icon, 0, TQT_TQOBJECT(this),
TQT_SIGNAL(fastForwardPlaybackToEnd()), actionCollection(),
"playback_pointer_end");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-record")));
- new KAction(i18n("&Record"), icon, 0, this,
+ new KAction(i18n("&Record"), icon, 0, TQT_TQOBJECT(this),
TQT_SIGNAL(record()), actionCollection(),
"record");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-panic")));
- new KAction(i18n("Panic"), icon, Key_P + CTRL + ALT, this,
+ new KAction(i18n("Panic"), icon, Key_P + CTRL + ALT, TQT_TQOBJECT(this),
TQT_SIGNAL(panic()), actionCollection(),
"panic");
unsigned int mixerOptions = m_studio->getMixerDisplayOptions();
- (new KToggleAction(i18n("Show Audio &Faders"), 0, this,
+ (new KToggleAction(i18n("Show Audio &Faders"), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotToggleFaders()), actionCollection(),
"show_audio_faders"))->setChecked
(!(mixerOptions & MIXER_OMIT_FADERS));
- (new KToggleAction(i18n("Show Synth &Faders"), 0, this,
+ (new KToggleAction(i18n("Show Synth &Faders"), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotToggleSynthFaders()), actionCollection(),
"show_synth_faders"))->setChecked
(!(mixerOptions & MIXER_OMIT_SYNTH_FADERS));
- (new KToggleAction(i18n("Show &Submasters"), 0, this,
+ (new KToggleAction(i18n("Show &Submasters"), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotToggleSubmasters()), actionCollection(),
"show_audio_submasters"))->setChecked
(!(mixerOptions & MIXER_OMIT_SUBMASTERS));
- (new KToggleAction(i18n("Show &Plugin Buttons"), 0, this,
+ (new KToggleAction(i18n("Show &Plugin Buttons"), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotTogglePluginButtons()), actionCollection(),
"show_plugin_buttons"))->setChecked
(!(mixerOptions & MIXER_OMIT_PLUGINS));
- (new KToggleAction(i18n("Show &Unassigned Faders"), 0, this,
+ (new KToggleAction(i18n("Show &Unassigned Faders"), 0, TQT_TQOBJECT(this),
TQT_SLOT(slotToggleUnassignedFaders()), actionCollection(),
"show_unassigned_faders"))->setChecked
(mixerOptions & MIXER_SHOW_UNASSIGNED_FADERS);
@@ -182,9 +182,9 @@ AudioMixerWindow::AudioMixerWindow(TQWidget *parent,
for (int i = 1; i <= 16; i *= 2) {
action =
new KRadioAction(i18n("1 Input", "%n Inputs", i),
- 0, this,
+ 0, TQT_TQOBJECT(this),
TQT_SLOT(slotSetInputCountFromAction()), actionCollection(),
- TQString("inputs_%1").arg(i));
+ TQString("inputs_%1").tqarg(i));
action->setExclusiveGroup("inputs");
if (i == int(m_studio->getRecordIns().size()))
action->setChecked(true);
@@ -192,7 +192,7 @@ AudioMixerWindow::AudioMixerWindow(TQWidget *parent,
action = new KRadioAction
(i18n("No Submasters"),
- 0, this,
+ 0, TQT_TQOBJECT(this),
TQT_SLOT(slotSetSubmasterCountFromAction()), actionCollection(),
TQString("submasters_0"));
action->setExclusiveGroup("submasters");
@@ -201,9 +201,9 @@ AudioMixerWindow::AudioMixerWindow(TQWidget *parent,
for (int i = 2; i <= 8; i *= 2) {
action = new KRadioAction
(i18n("1 Submaster", "%n Submasters", i),
- 0, this,
+ 0, TQT_TQOBJECT(this),
TQT_SLOT(slotSetSubmasterCountFromAction()), actionCollection(),
- TQString("submasters_%1").arg(i));
+ TQString("submasters_%1").tqarg(i));
action->setExclusiveGroup("submasters");
if (i == int(m_studio->getBusses().size()) - 1)
action->setChecked(true);
@@ -268,12 +268,12 @@ AudioMixerWindow::populate()
BussList busses = m_studio->getBusses();
TQString pixmapDir = KGlobal::dirs()->findResource("appdata", "pixmaps/");
- m_monoPixmap.load(TQString("%1/misc/mono.xpm").arg(pixmapDir));
- m_stereoPixmap.load(TQString("%1/misc/stereo.xpm").arg(pixmapDir));
+ m_monoPixmap.load(TQString("%1/misc/mono.xpm").tqarg(pixmapDir));
+ m_stereoPixmap.load(TQString("%1/misc/stereo.xpm").tqarg(pixmapDir));
// Total cols: is 2 for each fader, submaster or master, plus 1
// for each spacer.
- TQGridLayout *mainLayout = new QGridLayout
+ TQGridLayout *mainLayout = new TQGridLayout
(m_mainBox, (instruments.size() + busses.size()) * 3, 7);
setCaption(i18n("Audio Mixer"));
@@ -397,11 +397,11 @@ AudioMixerWindow::populate()
TQLabel *idLabel;
TQString idString;
if ((*i)->getType() == Instrument::Audio) {
- idString = i18n("Audio %1").arg((*i)->getId() -
+ idString = i18n("Audio %1").tqarg((*i)->getId() -
AudioInstrumentBase + 1);
idLabel = new TQLabel(idString, m_mainBox, "audioIdLabel");
} else {
- idString = i18n("Synth %1").arg((*i)->getId() -
+ idString = i18n("Synth %1").tqarg((*i)->getId() -
SoftSynthInstrumentBase + 1);
idLabel = new TQLabel(idString, m_mainBox, "synthIdLabel");
}
@@ -411,14 +411,14 @@ AudioMixerWindow::populate()
mainLayout->addMultiCellWidget(rec.m_input->getWidget(), 1, 1, col, col + 1);
}
mainLayout->addMultiCellWidget(rec.m_output->getWidget(), 2, 2, col, col + 1);
- // mainLayout->addWidget(idLabel, 2, col, Qt::AlignCenter);
- // mainLayout->addWidget(rec.m_pan, 2, col+1, Qt::AlignLeft);
+ // mainLayout->addWidget(idLabel, 2, col, TQt::AlignCenter);
+ // mainLayout->addWidget(rec.m_pan, 2, col+1, TQt::AlignLeft);
- mainLayout->addMultiCellWidget(idLabel, 0, 0, col, col + 1, Qt::AlignCenter);
- mainLayout->addWidget(rec.m_pan, 5, col, Qt::AlignCenter);
+ mainLayout->addMultiCellWidget(idLabel, 0, 0, col, col + 1, TQt::AlignCenter);
+ mainLayout->addWidget(rec.m_pan, 5, col, TQt::AlignCenter);
- mainLayout->addWidget(rec.m_fader, 3, col, Qt::AlignCenter);
- mainLayout->addWidget(rec.m_meter, 3, col + 1, Qt::AlignCenter);
+ mainLayout->addWidget(rec.m_fader, 3, col, TQt::AlignCenter);
+ mainLayout->addWidget(rec.m_meter, 3, col + 1, TQt::AlignCenter);
// commented out until implemented
// mainLayout->addWidget(rec.m_muteButton, 4, col);
@@ -525,17 +525,17 @@ AudioMixerWindow::populate()
this, TQT_SLOT(slotSelectPlugin()));
}
- TQLabel *idLabel = new TQLabel(i18n("Sub %1").arg(count), m_mainBox, "subMaster");
+ TQLabel *idLabel = new TQLabel(i18n("Sub %1").tqarg(count), m_mainBox, "subMaster");
idLabel->setFont(boldFont);
- // mainLayout->addWidget(idLabel, 2, col, Qt::AlignCenter);
- mainLayout->addMultiCellWidget(idLabel, 0, 0, col, col + 1, Qt::AlignCenter);
+ // mainLayout->addWidget(idLabel, 2, col, TQt::AlignCenter);
+ mainLayout->addMultiCellWidget(idLabel, 0, 0, col, col + 1, TQt::AlignCenter);
- // mainLayout->addWidget(rec.m_pan, 2, col+1, Qt::AlignLeft);
- mainLayout->addMultiCellWidget(rec.m_pan, 5, 5, col, col + 1, Qt::AlignCenter);
+ // mainLayout->addWidget(rec.m_pan, 2, col+1, TQt::AlignLeft);
+ mainLayout->addMultiCellWidget(rec.m_pan, 5, 5, col, col + 1, TQt::AlignCenter);
- mainLayout->addWidget(rec.m_fader, 3, col, Qt::AlignCenter);
- mainLayout->addWidget(rec.m_meter, 3, col + 1, Qt::AlignCenter);
+ mainLayout->addWidget(rec.m_fader, 3, col, TQt::AlignCenter);
+ mainLayout->addWidget(rec.m_meter, 3, col + 1, TQt::AlignCenter);
// mainLayout->addMultiCellWidget(rec.m_muteButton, 4, 4, col, col+1);
rec.m_muteButton->hide();
@@ -587,9 +587,9 @@ AudioMixerWindow::populate()
TQLabel *idLabel = new TQLabel(i18n("Master"), m_mainBox);
idLabel->setFont(boldFont);
- mainLayout->addMultiCellWidget(idLabel, 0, 0, col, col + 1, Qt::AlignCenter);
- mainLayout->addWidget(rec.m_fader, 3, col, Qt::AlignCenter);
- mainLayout->addWidget(rec.m_meter, 3, col + 1, Qt::AlignCenter);
+ mainLayout->addMultiCellWidget(idLabel, 0, 0, col, col + 1, TQt::AlignCenter);
+ mainLayout->addWidget(rec.m_fader, 3, col, TQt::AlignCenter);
+ mainLayout->addWidget(rec.m_meter, 3, col + 1, TQt::AlignCenter);
// mainLayout->addMultiCellWidget(rec.m_muteButton, 4, 4, col, col+1);
rec.m_muteButton->hide();
@@ -706,7 +706,7 @@ AudioMixerWindow::slotPluginSelected(InstrumentId id,
}
- rec.m_plugins[index]->setPaletteForegroundColor(Qt::white);
+ rec.m_plugins[index]->setPaletteForegroundColor(TQt::white);
rec.m_plugins[index]->setPaletteBackgroundColor(pluginBgColour);
}
} else if (id > 0 && id <= m_submasters.size()) {
@@ -745,7 +745,7 @@ AudioMixerWindow::slotPluginSelected(InstrumentId id,
}
- rec.m_plugins[index]->setPaletteForegroundColor(Qt::white);
+ rec.m_plugins[index]->setPaletteForegroundColor(TQt::white);
rec.m_plugins[index]->setPaletteBackgroundColor(pluginBgColour);
}
}
@@ -921,7 +921,7 @@ AudioMixerWindow::updatePluginButtons(int id)
} else if (used) {
- rec->m_plugins[i]->setPaletteForegroundColor(Qt::white);
+ rec->m_plugins[i]->setPaletteForegroundColor(TQt::white);
rec->m_plugins[i]->setPaletteBackgroundColor(pluginBgColour);
@@ -942,7 +942,7 @@ AudioMixerWindow::updatePluginButtons(int id)
void
AudioMixerWindow::slotSelectPlugin()
{
- const TQObject *s = sender();
+ const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
for (FaderMap::iterator i = m_faders.begin();
i != m_faders.end(); ++i) {
@@ -954,7 +954,7 @@ AudioMixerWindow::slotSelectPlugin()
for (std::vector<TQPushButton *>::iterator pli = i->second.m_plugins.begin();
pli != i->second.m_plugins.end(); ++pli) {
- if (*pli == s) {
+ if (TQT_BASE_OBJECT(*pli) == TQT_BASE_OBJECT_CONST(s)) {
emit selectPlugin(this, i->first, index);
return ;
@@ -977,7 +977,7 @@ AudioMixerWindow::slotSelectPlugin()
for (std::vector<TQPushButton *>::iterator pli = i->m_plugins.begin();
pli != i->m_plugins.end(); ++pli) {
- if (*pli == s) {
+ if (TQT_BASE_OBJECT(*pli) == TQT_BASE_OBJECT_CONST(s)) {
emit selectPlugin(this, b, index);
return ;
@@ -993,7 +993,7 @@ AudioMixerWindow::slotSelectPlugin()
void
AudioMixerWindow::slotInputChanged()
{
- const TQObject *s = sender();
+ const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
for (FaderMap::iterator i = m_faders.begin();
i != m_faders.end(); ++i) {
@@ -1006,7 +1006,7 @@ AudioMixerWindow::slotInputChanged()
void
AudioMixerWindow::slotOutputChanged()
{
- const TQObject *s = sender();
+ const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
for (FaderMap::iterator i = m_faders.begin();
i != m_faders.end(); ++i) {
@@ -1060,11 +1060,11 @@ AudioMixerWindow::sendControllerRefresh()
void
AudioMixerWindow::slotFaderLevelChanged(float dB)
{
- const TQObject *s = sender();
+ const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
BussList busses = m_studio->getBusses();
- if (m_master.m_fader == s) {
+ if (TQT_BASE_OBJECT(m_master.m_fader) == TQT_BASE_OBJECT_CONST(s)) {
if (busses.size() > 0) {
StudioControl::setStudioObjectProperty
@@ -1082,7 +1082,7 @@ AudioMixerWindow::slotFaderLevelChanged(float dB)
for (FaderVector::iterator i = m_submasters.begin();
i != m_submasters.end(); ++i) {
- if (i->m_fader == s) {
+ if (TQT_BASE_OBJECT(i->m_fader) == TQT_BASE_OBJECT_CONST(s)) {
if ((int)busses.size() > index) {
StudioControl::setStudioObjectProperty
(MappedObjectId(busses[index]->getMappedId()),
@@ -1102,7 +1102,7 @@ AudioMixerWindow::slotFaderLevelChanged(float dB)
for (FaderMap::iterator i = m_faders.begin();
i != m_faders.end(); ++i) {
- if (i->second.m_fader == s) {
+ if (TQT_BASE_OBJECT(i->second.m_fader) == TQT_BASE_OBJECT_CONST(s)) {
Instrument *instrument =
m_studio->getInstrumentById(i->first);
@@ -1140,7 +1140,7 @@ AudioMixerWindow::slotFaderLevelChanged(float dB)
void
AudioMixerWindow::slotPanChanged(float pan)
{
- const TQObject *s = sender();
+ const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
BussList busses = m_studio->getBusses();
@@ -1149,7 +1149,7 @@ AudioMixerWindow::slotPanChanged(float pan)
for (FaderVector::iterator i = m_submasters.begin();
i != m_submasters.end(); ++i) {
- if (i->m_pan == s) {
+ if (TQT_BASE_OBJECT(i->m_pan) == TQT_BASE_OBJECT_CONST(s)) {
if ((int)busses.size() > index) {
StudioControl::setStudioObjectProperty
(MappedObjectId(busses[index]->getMappedId()),
@@ -1168,7 +1168,7 @@ AudioMixerWindow::slotPanChanged(float pan)
for (FaderMap::iterator i = m_faders.begin();
i != m_faders.end(); ++i) {
- if (i->second.m_pan == s) {
+ if (TQT_BASE_OBJECT(i->second.m_pan) == TQT_BASE_OBJECT_CONST(s)) {
Instrument *instrument =
m_studio->getInstrumentById(i->first);
@@ -1208,7 +1208,7 @@ AudioMixerWindow::slotPanChanged(float pan)
void
AudioMixerWindow::slotChannelsChanged()
{
- const TQObject *s = sender();
+ const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
// channels are only switchable on instruments
@@ -1218,7 +1218,7 @@ AudioMixerWindow::slotChannelsChanged()
for (FaderMap::iterator i = m_faders.begin();
i != m_faders.end(); ++i) {
- if (s == i->second.m_stereoButton) {
+ if (TQT_BASE_OBJECT_CONST(s) == TQT_BASE_OBJECT(i->second.m_stereoButton)) {
Instrument *instrument =
m_studio->getInstrumentById(i->first);
@@ -1322,7 +1322,7 @@ AudioMixerWindow::updateMonitorMeters(SequencerMapper *mapper)
// only show monitor levels when quiescent or when recording (as
// record levels)
if (m_document->getSequenceManager() &&
- m_document->getSequenceManager()->getTransportStatus() == PLAYING) {
+ m_document->getSequenceManager()->getTransporttqStatus() == PLAYING) {
return ;
}
@@ -1444,7 +1444,7 @@ AudioMixerWindow::slotControllerDeviceEventReceived(MappedEvent *e,
void
AudioMixerWindow::slotSetInputCountFromAction()
{
- const TQObject *s = sender();
+ const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
TQString name = s->name();
if (name.left(7) == "inputs_") {
@@ -1475,7 +1475,7 @@ AudioMixerWindow::slotSetInputCountFromAction()
void
AudioMixerWindow::slotSetSubmasterCountFromAction()
{
- const TQObject *s = sender();
+ const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
TQString name = s->name();
if (name.left(11) == "submasters_") {
@@ -1714,7 +1714,7 @@ AudioMixerWindow::slotToggleUnassignedFaders()
void
AudioMixerWindow::toggleNamedWidgets(bool show, const char* const name)
{
- TQLayoutIterator it = m_mainBox->layout()->iterator();
+ TQLayoutIterator it = m_mainBox->tqlayout()->iterator();
TQLayoutItem *child;
while ( (child = it.current()) != 0 ) {
TQWidget * widget = child->widget();
diff --git a/src/gui/studio/AudioMixerWindow.h b/src/gui/studio/AudioMixerWindow.h
index cc3cd77..e5ec815 100644
--- a/src/gui/studio/AudioMixerWindow.h
+++ b/src/gui/studio/AudioMixerWindow.h
@@ -55,9 +55,10 @@ class AudioRouteMenu;
class AudioMixerWindow : public MixerWindow
{
Q_OBJECT
+ TQ_OBJECT
public:
- AudioMixerWindow(TQWidget *parent, RosegardenGUIDoc *document);
+ AudioMixerWindow(TQWidget *tqparent, RosegardenGUIDoc *document);
~AudioMixerWindow();
void updateMeters(SequencerMapper *mapper);
diff --git a/src/gui/studio/AudioPlugin.cpp b/src/gui/studio/AudioPlugin.cpp
index dd30472..c837fd7 100644
--- a/src/gui/studio/AudioPlugin.cpp
+++ b/src/gui/studio/AudioPlugin.cpp
@@ -52,7 +52,7 @@ AudioPlugin::AudioPlugin(const TQString &identifier,
m_isSynth(isSynth),
m_isGrouped(isGrouped),
m_category(category),
- m_colour(Qt::darkRed)
+ m_colour(TQt::darkRed)
{}
void
diff --git a/src/gui/studio/AudioPluginManager.h b/src/gui/studio/AudioPluginManager.h
index 9150f69..540f388 100644
--- a/src/gui/studio/AudioPluginManager.h
+++ b/src/gui/studio/AudioPluginManager.h
@@ -89,7 +89,7 @@ protected:
bool removePlugin(const TQString &identifier);
- class Enumerator : public QThread
+ class Enumerator : public TQThread
{
public:
Enumerator(AudioPluginManager *);
diff --git a/src/gui/studio/AudioPluginOSCGUI.cpp b/src/gui/studio/AudioPluginOSCGUI.cpp
index d443acd..3fd2ffb 100644
--- a/src/gui/studio/AudioPluginOSCGUI.cpp
+++ b/src/gui/studio/AudioPluginOSCGUI.cpp
@@ -86,7 +86,7 @@ AudioPluginOSCGUI::~AudioPluginOSCGUI()
quit();
}
-QString
+TQString
AudioPluginOSCGUI::getGUIFilePath(TQString identifier)
{
TQString type, soName, label;
diff --git a/src/gui/studio/AudioPluginOSCGUIManager.cpp b/src/gui/studio/AudioPluginOSCGUIManager.cpp
index e3d61d7..6662a53 100644
--- a/src/gui/studio/AudioPluginOSCGUIManager.cpp
+++ b/src/gui/studio/AudioPluginOSCGUIManager.cpp
@@ -329,7 +329,7 @@ AudioPluginOSCGUIManager::updateConfiguration(InstrumentId instrument, int posit
m_guis[instrument][position]->sendConfiguration(key, value);
}
-QString
+TQString
AudioPluginOSCGUIManager::getOSCUrl(InstrumentId instrument, int position,
TQString identifier)
{
@@ -345,18 +345,18 @@ AudioPluginOSCGUIManager::getOSCUrl(InstrumentId instrument, int position,
baseUrl += '/';
TQString url = TQString("%1%2/%3/%4/%5/%6")
- .arg(baseUrl)
- .arg("plugin")
- .arg(type)
- .arg(instrument);
+ .tqarg(baseUrl)
+ .tqarg("plugin")
+ .tqarg(type)
+ .tqarg(instrument);
if (position == int(Instrument::SYNTH_PLUGIN_POSITION)) {
- url = url.arg("synth");
+ url = url.tqarg("synth");
} else {
- url = url.arg(position);
+ url = url.tqarg(position);
}
- url = url.arg(label);
+ url = url.tqarg(label);
return url;
}
@@ -435,7 +435,7 @@ AudioPluginOSCGUIManager::parseOSCPath(TQString path, InstrumentId &instrument,
return true;
}
-QString
+TQString
AudioPluginOSCGUIManager::getFriendlyName(InstrumentId instrument, int position,
TQString)
{
@@ -444,10 +444,10 @@ AudioPluginOSCGUIManager::getFriendlyName(InstrumentId instrument, int position,
return i18n("Rosegarden Plugin");
else {
if (position == int(Instrument::SYNTH_PLUGIN_POSITION)) {
- return i18n("Rosegarden: %1").arg(strtoqstr(container->getPresentationName()));
+ return i18n("Rosegarden: %1").tqarg(strtoqstr(container->getPresentationName()));
} else {
- return i18n("Rosegarden: %1: %2").arg(strtoqstr(container->getPresentationName()))
- .arg(i18n("Plugin slot %1").arg(position));
+ return i18n("Rosegarden: %1: %2").tqarg(strtoqstr(container->getPresentationName()))
+ .tqarg(i18n("Plugin slot %1").tqarg(position));
}
}
}
diff --git a/src/gui/studio/BankEditorDialog.h b/src/gui/studio/BankEditorDialog.h
index 6e36bef..4ab64ea 100644
--- a/src/gui/studio/BankEditorDialog.h
+++ b/src/gui/studio/BankEditorDialog.h
@@ -61,9 +61,10 @@ class MidiDevice;
class BankEditorDialog : public KMainWindow
{
Q_OBJECT
+ TQ_OBJECT
public:
- BankEditorDialog(TQWidget *parent,
+ BankEditorDialog(TQWidget *tqparent,
RosegardenGUIDoc *doc,
DeviceId defaultDevice =
Device::NO_DEVICE);
diff --git a/src/gui/studio/ChangeRecordDeviceCommand.cpp b/src/gui/studio/ChangeRecordDeviceCommand.cpp
index 5f46eff..f596f1c 100644
--- a/src/gui/studio/ChangeRecordDeviceCommand.cpp
+++ b/src/gui/studio/ChangeRecordDeviceCommand.cpp
@@ -42,12 +42,12 @@ ChangeRecordDeviceCommand::swap()
TQString sdevice = TQString::number(m_deviceId);
if (m_action)
{
- if(!devList.contains(sdevice))
+ if(!devList.tqcontains(sdevice))
devList.append(sdevice);
}
else
{
- if(devList.contains(sdevice))
+ if(devList.tqcontains(sdevice))
devList.remove(sdevice);
}
config->writeEntry("midirecorddevice", devList);
diff --git a/src/gui/studio/DeviceEditorDialog.cpp b/src/gui/studio/DeviceEditorDialog.cpp
index 9f45c31..66f371a 100644
--- a/src/gui/studio/DeviceEditorDialog.cpp
+++ b/src/gui/studio/DeviceEditorDialog.cpp
@@ -55,9 +55,9 @@
namespace Rosegarden
{
-DeviceEditorDialog::DeviceEditorDialog(TQWidget *parent,
+DeviceEditorDialog::DeviceEditorDialog(TQWidget *tqparent,
RosegardenGUIDoc *document) :
- KDialogBase(parent, "deviceeditordialog", true,
+ KDialogBase(tqparent, "deviceeditordialog", true,
i18n("Manage MIDI Devices"), Ok | Apply | Close, Ok, true),
m_document(document),
m_studio(&document->getStudio()),
@@ -145,7 +145,7 @@ DeviceEditorDialog::populate()
MidiDevice *md = static_cast<MidiDevice *>(*it);
// if you change this string ("Device %1"), change test in slotApply
- TQString deviceName = i18n("Device %1").arg(md->getId() + 1);
+ TQString deviceName = i18n("Device %1").tqarg(md->getId() + 1);
TQString deviceLabel = strtoqstr(md->getName());
TQString connectionName = strtoqstr(md->getConnection());
@@ -221,7 +221,7 @@ DeviceEditorDialog::makeConnectionList(unsigned int direction,
TQDataStream reply(replyData, IO_ReadOnly);
TQString connection;
- if (replyType == "TQString") {
+ if (replyType == TQSTRING_OBJECT_NAME_STRING) {
reply >> connection;
list.append(connection);
}
diff --git a/src/gui/studio/DeviceEditorDialog.h b/src/gui/studio/DeviceEditorDialog.h
index 44247b3..7eea5a7 100644
--- a/src/gui/studio/DeviceEditorDialog.h
+++ b/src/gui/studio/DeviceEditorDialog.h
@@ -46,8 +46,9 @@ class RosegardenGUIDoc;
class DeviceEditorDialog : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- DeviceEditorDialog(TQWidget *parent, RosegardenGUIDoc *document);
+ DeviceEditorDialog(TQWidget *tqparent, RosegardenGUIDoc *document);
~DeviceEditorDialog();
void setModified(bool value);
diff --git a/src/gui/studio/DeviceManagerDialog.cpp b/src/gui/studio/DeviceManagerDialog.cpp
index eb40c77..84aa0ca 100644
--- a/src/gui/studio/DeviceManagerDialog.cpp
+++ b/src/gui/studio/DeviceManagerDialog.cpp
@@ -83,9 +83,9 @@ static const int RECORD_CURRENT_COL = 1;
static const int RECORD_CONNECTION_COL = 2;
-DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
+DeviceManagerDialog::DeviceManagerDialog(TQWidget *tqparent,
RosegardenGUIDoc *document) :
- KMainWindow(parent, "deviceeditordialog"),
+ KMainWindow(tqparent, "deviceeditordialog"),
m_document(document),
m_studio(&document->getStudio())
{
@@ -95,7 +95,7 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
setCaption(i18n("Manage MIDI Devices"));
- TQGroupBox *groupBox = new TQGroupBox(2, Horizontal, i18n("Play devices"), mainBox);
+ TQGroupBox *groupBox = new TQGroupBox(2, Qt::Horizontal, i18n("Play devices"), mainBox);
m_playTable = new TQTable(0, 2, groupBox);
m_playTable->setSorting(false);
@@ -110,16 +110,16 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
m_playTable->setSelectionMode(TQTable::SingleRow);
TQFrame *frame = new TQFrame(groupBox);
- TQVBoxLayout *vlayout = new TQVBoxLayout(frame);
- TQGrid *buttons = new TQGrid(2, Horizontal, frame);
+ TQVBoxLayout *vtqlayout = new TQVBoxLayout(frame);
+ TQGrid *buttons = new TQGrid(2, Qt::Horizontal, frame);
TQPushButton *addButton = new TQPushButton(i18n("New"), buttons);
m_deletePlayButton = new TQPushButton(i18n("Delete"), buttons);
m_importButton = new TQPushButton(i18n("Import..."), buttons);
m_exportButton = new TQPushButton(i18n("Export..."), buttons);
m_banksButton = new TQPushButton(i18n("Banks..."), buttons);
m_controllersButton = new TQPushButton(i18n("Control Events..."), buttons);
- vlayout->addWidget(buttons);
- vlayout->addStretch(10);
+ vtqlayout->addWidget(buttons);
+ vtqlayout->addStretch(10);
TQToolTip::add
(addButton,
@@ -153,7 +153,7 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
this, TQT_SLOT(slotPlayDeviceSelected (int, int)));
mainLayout->addWidget(groupBox);
- groupBox = new TQGroupBox(2, Horizontal, i18n("Record devices"), mainBox);
+ groupBox = new TQGroupBox(2, Qt::Horizontal, i18n("Record devices"), mainBox);
m_recordTable = new TQTable(0, 3, groupBox);
m_recordTable->setSorting(false);
@@ -169,12 +169,12 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
m_recordTable->setSelectionMode(TQTable::SingleRow);
frame = new TQFrame(groupBox);
- vlayout = new TQVBoxLayout(frame);
- buttons = new TQGrid(2, Horizontal, frame);
+ vtqlayout = new TQVBoxLayout(frame);
+ buttons = new TQGrid(2, Qt::Horizontal, frame);
addButton = new TQPushButton(i18n("New"), buttons);
m_deleteRecordButton = new TQPushButton(i18n("Delete"), buttons);
- vlayout->addWidget(buttons);
- vlayout->addStretch(10);
+ vtqlayout->addWidget(buttons);
+ vtqlayout->addStretch(10);
TQToolTip::add
(addButton,
@@ -204,17 +204,17 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
TQFrame* btnBox = new TQFrame(mainBox);
- btnBox->setSizePolicy(
+ btnBox->tqsetSizePolicy(
TQSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Fixed));
TQPushButton *closeButton = new TQPushButton(i18n("Close"), btnBox);
- TQHBoxLayout* layout = new TQHBoxLayout(btnBox, 0, 10);
- layout->addStretch(10);
- layout->addWidget(closeButton);
- layout->addSpacing(5);
+ TQHBoxLayout* tqlayout = new TQHBoxLayout(btnBox, 0, 10);
+ tqlayout->addStretch(10);
+ tqlayout->addWidget(closeButton);
+ tqlayout->addSpacing(5);
- KAction* close = KStdAction::close(this,
+ KAction* close = KStdAction::close(TQT_TQOBJECT(this),
TQT_SLOT(slotClose()),
actionCollection());
@@ -326,7 +326,7 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
m_playTable->insertRows(deviceCount, 1);
- TQString deviceName = i18n("%1").arg(deviceCount + 1);
+ TQString deviceName = i18n("%1").tqarg(deviceCount + 1);
TQString connectionName = strtoqstr((*it)->getConnection());
m_playTable->setText(deviceCount, PLAY_NAME_COL,
@@ -360,7 +360,7 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
m_recordTable->insertRows(deviceCount, 1);
- TQString deviceName = i18n("%1").arg(deviceCount + 1);
+ TQString deviceName = i18n("%1").tqarg(deviceCount + 1);
TQString connectionName = strtoqstr((*it)->getConnection());
m_recordTable->setText(deviceCount, RECORD_NAME_COL,
@@ -443,7 +443,7 @@ DeviceManagerDialog::DeviceManagerDialog(TQWidget *parent,
TQDataStream reply(replyData, IO_ReadOnly);
TQString connection;
- if (replyType == "TQString") {
+ if (replyType == TQSTRING_OBJECT_NAME_STRING) {
reply >> connection;
list.append(connection);
}
diff --git a/src/gui/studio/DeviceManagerDialog.h b/src/gui/studio/DeviceManagerDialog.h
index 84dceab..09e908d 100644
--- a/src/gui/studio/DeviceManagerDialog.h
+++ b/src/gui/studio/DeviceManagerDialog.h
@@ -50,8 +50,9 @@ class MidiDevice;
class DeviceManagerDialog : public KMainWindow
{
Q_OBJECT
+ TQ_OBJECT
public:
- DeviceManagerDialog(TQWidget *parent, RosegardenGUIDoc *document);
+ DeviceManagerDialog(TQWidget *tqparent, RosegardenGUIDoc *document);
~DeviceManagerDialog();
void setModified(bool value);
diff --git a/src/gui/studio/MidiBankListViewItem.cpp b/src/gui/studio/MidiBankListViewItem.cpp
index d3c9fb5..bb15ed4 100644
--- a/src/gui/studio/MidiBankListViewItem.cpp
+++ b/src/gui/studio/MidiBankListViewItem.cpp
@@ -37,10 +37,10 @@ namespace Rosegarden
MidiBankListViewItem::MidiBankListViewItem(DeviceId deviceId,
int bankNb,
- TQListViewItem* parent,
+ TQListViewItem* tqparent,
TQString name,
bool percussion, int msb, int lsb)
- : MidiDeviceListViewItem(deviceId, parent, name, percussion, msb, lsb),
+ : MidiDeviceListViewItem(deviceId, tqparent, name, percussion, msb, lsb),
m_percussion(percussion),
m_bankNb(bankNb)
{}
@@ -86,7 +86,7 @@ int MidiBankListViewItem::compare(TQListViewItem *i, int col, bool ascending) co
}
}
- // 'ascending' should be ignored according to Qt docs
+ // 'ascending' should be ignored according to TQt docs
//
return
thisVal > otherVal ? 1 :
diff --git a/src/gui/studio/MidiBankListViewItem.h b/src/gui/studio/MidiBankListViewItem.h
index 5d42160..a160374 100644
--- a/src/gui/studio/MidiBankListViewItem.h
+++ b/src/gui/studio/MidiBankListViewItem.h
@@ -44,7 +44,7 @@ class MidiBankListViewItem : public MidiDeviceListViewItem
public:
MidiBankListViewItem(DeviceId deviceId,
int bankNb,
- TQListViewItem* parent, TQString name,
+ TQListViewItem* tqparent, TQString name,
bool percussion,
int msb, int lsb);
diff --git a/src/gui/studio/MidiDeviceListViewItem.cpp b/src/gui/studio/MidiDeviceListViewItem.cpp
index 21a8cda..723e6fa 100644
--- a/src/gui/studio/MidiDeviceListViewItem.cpp
+++ b/src/gui/studio/MidiDeviceListViewItem.cpp
@@ -35,24 +35,24 @@ namespace Rosegarden
{
MidiDeviceListViewItem::MidiDeviceListViewItem(DeviceId deviceId,
- TQListView* parent, TQString name)
- : KListViewItem(parent, name),
+ TQListView* tqparent, TQString name)
+ : KListViewItem(tqparent, name),
m_deviceId(deviceId)
{}
MidiDeviceListViewItem::MidiDeviceListViewItem(DeviceId deviceId,
- TQListViewItem* parent, TQString name,
+ TQListViewItem* tqparent, TQString name,
bool percussion,
int msb, int lsb)
- : KListViewItem(parent, name,
+ : KListViewItem(tqparent, name,
TQString(percussion ? i18n("Percussion Bank") : i18n("Bank")),
TQString().setNum(msb), TQString().setNum(lsb)),
m_deviceId(deviceId)
{}
MidiDeviceListViewItem::MidiDeviceListViewItem(DeviceId deviceId,
- TQListViewItem* parent, TQString name)
-: KListViewItem(parent, name, i18n("Key Mapping"), "", ""),
+ TQListViewItem* tqparent, TQString name)
+: KListViewItem(tqparent, name, i18n("Key Mapping"), "", ""),
m_deviceId(deviceId)
{}
@@ -78,7 +78,7 @@ int MidiDeviceListViewItem::compare(TQListViewItem *i, int col, bool ascending)
}
}
- // 'ascending' should be ignored according to Qt docs
+ // 'ascending' should be ignored according to TQt docs
//
return (thisVal > otherVal) ? 1 : -1;
diff --git a/src/gui/studio/MidiDeviceListViewItem.h b/src/gui/studio/MidiDeviceListViewItem.h
index a17a46c..554c62e 100644
--- a/src/gui/studio/MidiDeviceListViewItem.h
+++ b/src/gui/studio/MidiDeviceListViewItem.h
@@ -41,17 +41,17 @@ class MidiDeviceListViewItem : public KListViewItem
public:
// Device
MidiDeviceListViewItem(DeviceId id,
- TQListView* parent, TQString name);
+ TQListView* tqparent, TQString name);
// Bank
MidiDeviceListViewItem(DeviceId id,
- TQListViewItem* parent, TQString name,
+ TQListViewItem* tqparent, TQString name,
bool percussion,
int msb, int lsb);
// Key Mapping
MidiDeviceListViewItem(DeviceId id,
- TQListViewItem* parent, TQString name);
+ TQListViewItem* tqparent, TQString name);
DeviceId getDeviceId() const { return m_deviceId; }
diff --git a/src/gui/studio/MidiKeyMapListViewItem.cpp b/src/gui/studio/MidiKeyMapListViewItem.cpp
index dd77055..93c1532 100644
--- a/src/gui/studio/MidiKeyMapListViewItem.cpp
+++ b/src/gui/studio/MidiKeyMapListViewItem.cpp
@@ -36,9 +36,9 @@ namespace Rosegarden
{
MidiKeyMapListViewItem::MidiKeyMapListViewItem(DeviceId deviceId,
- TQListViewItem* parent,
+ TQListViewItem* tqparent,
TQString name)
- : MidiDeviceListViewItem(deviceId, parent, name),
+ : MidiDeviceListViewItem(deviceId, tqparent, name),
m_name(name)
{
setText(1, i18n("Key Mapping"));
diff --git a/src/gui/studio/MidiKeyMapListViewItem.h b/src/gui/studio/MidiKeyMapListViewItem.h
index d29b0a6..c658e73 100644
--- a/src/gui/studio/MidiKeyMapListViewItem.h
+++ b/src/gui/studio/MidiKeyMapListViewItem.h
@@ -43,7 +43,7 @@ class MidiKeyMapListViewItem : public MidiDeviceListViewItem
{
public:
MidiKeyMapListViewItem(DeviceId deviceId,
- TQListViewItem* parent, TQString name);
+ TQListViewItem* tqparent, TQString name);
virtual int compare(TQListViewItem *i, int col, bool ascending) const;
diff --git a/src/gui/studio/MidiKeyMappingEditor.cpp b/src/gui/studio/MidiKeyMappingEditor.cpp
index a9e347c..93fd33f 100644
--- a/src/gui/studio/MidiKeyMappingEditor.cpp
+++ b/src/gui/studio/MidiKeyMappingEditor.cpp
@@ -51,11 +51,11 @@ namespace Rosegarden
{
MidiKeyMappingEditor::MidiKeyMappingEditor(BankEditorDialog* bankEditor,
- TQWidget* parent,
+ TQWidget* tqparent,
const char* name)
: NameSetEditor(bankEditor,
i18n("Key Mapping details"),
- parent, name, i18n("Pitches"), false),
+ tqparent, name, i18n("Pitches"), false),
m_device(0)
{
TQWidget *additionalWidget = makeAdditionalWidget(m_mainFrame);
@@ -65,7 +65,7 @@ MidiKeyMappingEditor::MidiKeyMappingEditor(BankEditorDialog* bankEditor,
}
TQWidget *
-MidiKeyMappingEditor::makeAdditionalWidget(TQWidget *parent)
+MidiKeyMappingEditor::makeAdditionalWidget(TQWidget *tqparent)
{
return 0;
}
@@ -162,7 +162,7 @@ MidiKeyMappingEditor::slotNameChanged(const TQString& name)
return ;
}
- TQString senderName = sender()->name();
+ TQString senderName = TQT_TQOBJECT_CONST(sender())->name();
// Adjust value back to zero rated
//
diff --git a/src/gui/studio/MidiKeyMappingEditor.h b/src/gui/studio/MidiKeyMappingEditor.h
index 563501e..4f10ea6 100644
--- a/src/gui/studio/MidiKeyMappingEditor.h
+++ b/src/gui/studio/MidiKeyMappingEditor.h
@@ -46,10 +46,11 @@ class BankEditorDialog;
class MidiKeyMappingEditor : public NameSetEditor
{
Q_OBJECT
+ TQ_OBJECT
public:
MidiKeyMappingEditor(BankEditorDialog *bankEditor,
- TQWidget *parent,
+ TQWidget *tqparent,
const char *name = 0);
void clearAll();
@@ -62,7 +63,7 @@ public slots:
virtual void slotEntryButtonPressed();
protected:
- virtual TQWidget *makeAdditionalWidget(TQWidget *parent);
+ virtual TQWidget *makeAdditionalWidget(TQWidget *tqparent);
void blockAllSignals(bool block);
//--------------- Data members ---------------------------------
diff --git a/src/gui/studio/MidiMixerVUMeter.cpp b/src/gui/studio/MidiMixerVUMeter.cpp
index b882dec..8f1e1e5 100644
--- a/src/gui/studio/MidiMixerVUMeter.cpp
+++ b/src/gui/studio/MidiMixerVUMeter.cpp
@@ -32,14 +32,14 @@
namespace Rosegarden
{
-MidiMixerVUMeter::MidiMixerVUMeter(TQWidget *parent,
+MidiMixerVUMeter::MidiMixerVUMeter(TQWidget *tqparent,
VUMeterType type,
int width,
int height,
const char *name):
- VUMeter(parent, type, false, false, width, height, VUMeter::Vertical, name)
+ VUMeter(tqparent, type, false, false, width, height, VUMeter::Vertical, name)
{
- setAlignment(AlignCenter);
+ tqsetAlignment(AlignCenter);
}
void
diff --git a/src/gui/studio/MidiMixerVUMeter.h b/src/gui/studio/MidiMixerVUMeter.h
index 70622b2..4af8e81 100644
--- a/src/gui/studio/MidiMixerVUMeter.h
+++ b/src/gui/studio/MidiMixerVUMeter.h
@@ -40,7 +40,7 @@ namespace Rosegarden
class MidiMixerVUMeter : public VUMeter
{
public:
- MidiMixerVUMeter(TQWidget *parent = 0,
+ MidiMixerVUMeter(TQWidget *tqparent = 0,
VUMeterType type = Plain,
int width = 0,
int height = 0,
diff --git a/src/gui/studio/MidiMixerWindow.cpp b/src/gui/studio/MidiMixerWindow.cpp
index 047ba39..cb65b09 100644
--- a/src/gui/studio/MidiMixerWindow.cpp
+++ b/src/gui/studio/MidiMixerWindow.cpp
@@ -63,66 +63,66 @@
namespace Rosegarden
{
-MidiMixerWindow::MidiMixerWindow(TQWidget *parent,
+MidiMixerWindow::MidiMixerWindow(TQWidget *tqparent,
RosegardenGUIDoc *document):
- MixerWindow(parent, document),
+ MixerWindow(tqparent, document),
m_tabFrame(0)
{
// Initial setup
//
setupTabs();
- KStdAction::close(this,
+ KStdAction::close(TQT_TQOBJECT(this),
TQT_SLOT(slotClose()),
actionCollection());
- TQIconSet icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ TQIconSet icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-play")));
- KAction *play = new KAction(i18n("&Play"), icon, Key_Enter, this,
+ KAction *play = new KAction(i18n("&Play"), icon, Key_Enter, TQT_TQOBJECT(this),
TQT_SIGNAL(play()), actionCollection(), "play");
// Alternative shortcut for Play
KShortcut playShortcut = play->shortcut();
playShortcut.append( KKey(Key_Return + CTRL) );
play->setShortcut(playShortcut);
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-stop")));
- new KAction(i18n("&Stop"), icon, Key_Insert, this,
+ new KAction(i18n("&Stop"), icon, Key_Insert, TQT_TQOBJECT(this),
TQT_SIGNAL(stop()), actionCollection(), "stop");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-rewind")));
- new KAction(i18n("Re&wind"), icon, Key_End, this,
+ new KAction(i18n("Re&wind"), icon, Key_End, TQT_TQOBJECT(this),
TQT_SIGNAL(rewindPlayback()), actionCollection(),
"playback_pointer_back_bar");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-ffwd")));
- new KAction(i18n("&Fast Forward"), icon, Key_PageDown, this,
+ new KAction(i18n("&Fast Forward"), icon, Key_PageDown, TQT_TQOBJECT(this),
TQT_SIGNAL(fastForwardPlayback()), actionCollection(),
"playback_pointer_forward_bar");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-rewind-end")));
- new KAction(i18n("Rewind to &Beginning"), icon, 0, this,
+ new KAction(i18n("Rewind to &Beginning"), icon, 0, TQT_TQOBJECT(this),
TQT_SIGNAL(rewindPlaybackToBeginning()), actionCollection(),
"playback_pointer_start");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-ffwd-end")));
- new KAction(i18n("Fast Forward to &End"), icon, 0, this,
+ new KAction(i18n("Fast Forward to &End"), icon, 0, TQT_TQOBJECT(this),
TQT_SIGNAL(fastForwardPlaybackToEnd()), actionCollection(),
"playback_pointer_end");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-record")));
- new KAction(i18n("&Record"), icon, 0, this,
+ new KAction(i18n("&Record"), icon, 0, TQT_TQOBJECT(this),
TQT_SIGNAL(record()), actionCollection(),
"record");
- icon = TQIconSet(NotePixmapFactory::toQPixmap(NotePixmapFactory::makeToolbarPixmap
+ icon = TQIconSet(NotePixmapFactory::toTQPixmap(NotePixmapFactory::makeToolbarPixmap
("transport-panic")));
- new KAction(i18n("Panic"), icon, Key_P + CTRL + ALT, this,
+ new KAction(i18n("Panic"), icon, Key_P + CTRL + ALT, TQT_TQOBJECT(this),
TQT_SIGNAL(panic()), actionCollection(),
"panic");
@@ -171,39 +171,39 @@ MidiMixerWindow::setupTabs()
m_tabFrame->setFrameStyle(TQFrame::TabWidgetPanel);
m_tabFrame->setMargin(10);
- TQGridLayout *mainLayout = new QGridLayout
+ TQGridLayout *mainLayout = new TQGridLayout
(m_tabFrame, instruments.size() + 4, controls.size() + 4, 5);
// MIDI Mixer label
//
//TQLabel *label = new TQLabel(TQString("%1 %2").
//arg(strtoqstr(dev->getName()))
- //.arg(i18n("MIDI Mixer")), m_tabFrame);
+ //.tqarg(i18n("MIDI Mixer")), m_tabFrame);
TQLabel *label = new TQLabel("", m_tabFrame);
- mainLayout->addMultiCellWidget(label, 0, 0, 0, 16, Qt::AlignCenter);
+ mainLayout->addMultiCellWidget(label, 0, 0, 0, 16, TQt::AlignCenter);
// control labels
for (unsigned int i = 0; i < controls.size(); ++i) {
label = new TQLabel(strtoqstr(controls[i].getName()), m_tabFrame);
- mainLayout->addWidget(label, i + 1, 0, Qt::AlignCenter);
+ mainLayout->addWidget(label, i + 1, 0, TQt::AlignCenter);
}
// meter label
//
//label = new TQLabel(i18n("Meter"), m_tabFrame);
//mainLayout->addWidget(label,
- //controls.size() + 1, 0, Qt::AlignCenter);
+ //controls.size() + 1, 0, TQt::AlignCenter);
// volume label
label = new TQLabel(i18n("Volume"), m_tabFrame);
mainLayout->addWidget(label, controls.size() + 2, 0,
- Qt::AlignCenter);
+ TQt::AlignCenter);
// instrument label
label = new TQLabel(i18n("Instrument"), m_tabFrame);
mainLayout->addWidget(label, controls.size() + 3, 0,
- Qt::AlignCenter);
+ TQt::AlignCenter);
int posCount = 1;
int firstInstrument = -1;
@@ -223,7 +223,7 @@ MidiMixerWindow::setupTabs()
// Add the controls
//
for (unsigned int i = 0; i < controls.size(); ++i) {
- TQColor knobColour = Qt::white;
+ TQColor knobColour = TQt::white;
if (controls[i].getColourIndex() > 0) {
Colour c =
@@ -252,7 +252,7 @@ MidiMixerWindow::setupTabs()
this, TQT_SLOT(slotControllerChanged(float)));
mainLayout->addWidget(controller, i + 1, posCount,
- Qt::AlignCenter);
+ TQt::AlignCenter);
// Store the rotary
//
@@ -267,7 +267,7 @@ MidiMixerWindow::setupTabs()
new MidiMixerVUMeter(m_tabFrame,
VUMeter::FixedHeightVisiblePeakHold, 6, 30);
mainLayout->addWidget(meter, controls.size() + 1,
- posCount, Qt::AlignCenter);
+ posCount, TQt::AlignCenter);
m_faders[faderCount]->m_vuMeter = meter;
// Volume fader
@@ -275,7 +275,7 @@ MidiMixerWindow::setupTabs()
Fader *fader =
new Fader(0, 127, 100, 20, 80, m_tabFrame);
mainLayout->addWidget(fader, controls.size() + 2,
- posCount, Qt::AlignCenter);
+ posCount, TQt::AlignCenter);
m_faders[faderCount]->m_volumeFader = fader;
//fader->setFader(float((*iIt)->getVolume()));
@@ -286,7 +286,7 @@ MidiMixerWindow::setupTabs()
m_tabFrame, "idLabel");
mainLayout->addWidget(idLabel, controls.size() + 3,
- posCount, Qt::AlignCenter);
+ posCount, TQt::AlignCenter);
// store id in struct
m_faders[faderCount]->m_id = (*iIt)->getId();
@@ -306,8 +306,8 @@ MidiMixerWindow::setupTabs()
faderCount++;
}
- TQString name = TQString("%1 (%2)").arg(strtoqstr(dev->getName()))
- .arg(deviceCount++);
+ TQString name = TQString("%1 (%2)").tqarg(strtoqstr(dev->getName()))
+ .tqarg(deviceCount++);
addTab(m_tabFrame, name);
}
@@ -323,11 +323,11 @@ MidiMixerWindow::addTab(TQWidget *tab, const TQString &title)
void
MidiMixerWindow::slotFaderLevelChanged(float value)
{
- const TQObject *s = sender();
+ const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
for (FaderVector::const_iterator it = m_faders.begin();
it != m_faders.end(); ++it) {
- if ((*it)->m_volumeFader == s) {
+ if (TQT_BASE_OBJECT((*it)->m_volumeFader) == TQT_BASE_OBJECT_CONST(s)) {
Instrument *instr = m_studio->
getInstrumentById((*it)->m_id);
@@ -376,12 +376,12 @@ MidiMixerWindow::slotFaderLevelChanged(float value)
void
MidiMixerWindow::slotControllerChanged(float value)
{
- const TQObject *s = sender();
+ const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
unsigned int i = 0, j = 0;
for (i = 0; i < m_faders.size(); ++i) {
for (j = 0; j < m_faders[i]->m_controllerRotaries.size(); ++j) {
- if (m_faders[i]->m_controllerRotaries[j].second == s)
+ if (TQT_BASE_OBJECT(m_faders[i]->m_controllerRotaries[j].second) == TQT_BASE_OBJECT_CONST(s))
break;
}
diff --git a/src/gui/studio/MidiMixerWindow.h b/src/gui/studio/MidiMixerWindow.h
index 28ab9e3..8b98364 100644
--- a/src/gui/studio/MidiMixerWindow.h
+++ b/src/gui/studio/MidiMixerWindow.h
@@ -51,9 +51,10 @@ class Fader;
class MidiMixerWindow : public MixerWindow
{
Q_OBJECT
+ TQ_OBJECT
public:
- MidiMixerWindow(TQWidget *parent, RosegardenGUIDoc *document);
+ MidiMixerWindow(TQWidget *tqparent, RosegardenGUIDoc *document);
/**
* Setup the tabs on the Mixer according to the Studio
diff --git a/src/gui/studio/MidiProgramsEditor.cpp b/src/gui/studio/MidiProgramsEditor.cpp
index e69b1a9..08c0114 100644
--- a/src/gui/studio/MidiProgramsEditor.cpp
+++ b/src/gui/studio/MidiProgramsEditor.cpp
@@ -60,11 +60,11 @@ namespace Rosegarden
{
MidiProgramsEditor::MidiProgramsEditor(BankEditorDialog* bankEditor,
- TQWidget* parent,
+ TQWidget* tqparent,
const char* name)
: NameSetEditor(bankEditor,
i18n("Bank and Program details"),
- parent, name, i18n("Programs"), true),
+ tqparent, name, i18n("Programs"), true),
m_device(0),
m_bankList(bankEditor->getBankList()),
m_programList(bankEditor->getProgramList()),
@@ -77,9 +77,9 @@ MidiProgramsEditor::MidiProgramsEditor(BankEditorDialog* bankEditor,
}
TQWidget *
-MidiProgramsEditor::makeAdditionalWidget(TQWidget *parent)
+MidiProgramsEditor::makeAdditionalWidget(TQWidget *tqparent)
{
- TQFrame *frame = new TQFrame(parent);
+ TQFrame *frame = new TQFrame(tqparent);
m_percussion = new TQCheckBox(frame);
m_msb = new TQSpinBox(frame);
@@ -251,7 +251,7 @@ MidiProgramsEditor::populate(TQListViewItem* item)
getEntryButton(i)->setPixmap(keyPixmap);
TQToolTip::add
(getEntryButton(i),
- i18n("Key Mapping: %1").arg(
+ i18n("Key Mapping: %1").tqarg(
strtoqstr(m_device->getKeyMappingForProgram(*it)->getName())));
}
@@ -391,7 +391,7 @@ MidiProgramsEditor::slotNameChanged(const TQString& programName)
return ;
}
- TQString senderName = sender()->name();
+ TQString senderName = TQT_TQOBJECT_CONST(sender())->name();
// Adjust value back to zero rated
//
@@ -444,9 +444,9 @@ MidiProgramsEditor::slotNameChanged(const TQString& programName)
void
MidiProgramsEditor::slotEntryButtonPressed()
{
- TQPushButton* button = dynamic_cast<TQPushButton*>(const_cast<TQObject *>(sender()));
+ TQPushButton* button = dynamic_cast<TQPushButton*>(TQT_TQWIDGET(const_cast<TQT_BASE_OBJECT_NAME*>(sender())));
if (!button) {
- RG_DEBUG << "MidiProgramsEditor::slotEntryButtonPressed() : %%% ERROR - signal sender is not a QPushButton\n";
+ RG_DEBUG << "MidiProgramsEditor::slotEntryButtonPressed() : %%% ERROR - signal sender is not a TQPushButton\n";
return ;
}
@@ -538,7 +538,7 @@ MidiProgramsEditor::slotEntryMenuItemSelected(int i)
btn->setPixmap(TQPixmap(file));
}
TQToolTip::add
- (btn, i18n("Key Mapping: %1").arg(strtoqstr(newMapping)));
+ (btn, i18n("Key Mapping: %1").tqarg(strtoqstr(newMapping)));
}
btn->setEnabled(haveKeyMappings);
}
diff --git a/src/gui/studio/MidiProgramsEditor.h b/src/gui/studio/MidiProgramsEditor.h
index 64375cb..a71ca5a 100644
--- a/src/gui/studio/MidiProgramsEditor.h
+++ b/src/gui/studio/MidiProgramsEditor.h
@@ -49,9 +49,10 @@ class BankEditorDialog;
class MidiProgramsEditor : public NameSetEditor
{
Q_OBJECT
+ TQ_OBJECT
public:
MidiProgramsEditor(BankEditorDialog *bankEditor,
- TQWidget *parent,
+ TQWidget *tqparent,
const char *name = 0);
void clearAll();
@@ -93,7 +94,7 @@ protected:
void setBankName(const TQString& s);
- virtual TQWidget *makeAdditionalWidget(TQWidget *parent);
+ virtual TQWidget *makeAdditionalWidget(TQWidget *tqparent);
void blockAllSignals(bool block);
diff --git a/src/gui/studio/MixerWindow.cpp b/src/gui/studio/MixerWindow.cpp
index d0c233a..e27299d 100644
--- a/src/gui/studio/MixerWindow.cpp
+++ b/src/gui/studio/MixerWindow.cpp
@@ -37,9 +37,9 @@
namespace Rosegarden
{
-MixerWindow::MixerWindow(TQWidget *parent,
+MixerWindow::MixerWindow(TQWidget *tqparent,
RosegardenGUIDoc *document) :
- KMainWindow(parent, "mixerwindow"),
+ KMainWindow(tqparent, "mixerwindow"),
m_document(document),
m_studio(&document->getStudio()),
m_currentId(0)
diff --git a/src/gui/studio/MixerWindow.h b/src/gui/studio/MixerWindow.h
index 94d8bee..f4ff441 100644
--- a/src/gui/studio/MixerWindow.h
+++ b/src/gui/studio/MixerWindow.h
@@ -45,9 +45,10 @@ class RosegardenGUIDoc;
class MixerWindow: public KMainWindow
{
Q_OBJECT
+ TQ_OBJECT
public:
- MixerWindow(TQWidget *parent, RosegardenGUIDoc *document);
+ MixerWindow(TQWidget *tqparent, RosegardenGUIDoc *document);
TQAccel* getAccelerators() { return m_accelerators; }
signals:
diff --git a/src/gui/studio/NameSetEditor.cpp b/src/gui/studio/NameSetEditor.cpp
index 6fa9bbe..396112d 100644
--- a/src/gui/studio/NameSetEditor.cpp
+++ b/src/gui/studio/NameSetEditor.cpp
@@ -48,11 +48,11 @@ namespace Rosegarden
NameSetEditor::NameSetEditor(BankEditorDialog* bankEditor,
TQString title,
- TQWidget* parent,
+ TQWidget* tqparent,
const char* name,
TQString headingPrefix,
bool showEntryButtons)
- : TQVGroupBox(title, parent, name),
+ : TQVGroupBox(title, tqparent, name),
m_bankEditor(bankEditor),
m_mainFrame(new TQFrame(this))
{
@@ -99,7 +99,7 @@ NameSetEditor::NameSetEditor(BankEditorDialog* bankEditor,
for (unsigned int row = 0; row < 128 / (tabs*cols); ++row) {
numBox = new TQHBox(v);
- TQString numberText = TQString("%1").arg(labelId + 1);
+ TQString numberText = TQString("%1").tqarg(labelId + 1);
if (tab == 0 && col == 0 && row == 0) {
// Initial label; button to adjust whether labels start at 0 or 1
@@ -111,7 +111,7 @@ NameSetEditor::NameSetEditor(BankEditorDialog* bankEditor,
} else {
TQLabel *label = new TQLabel(numberText, numBox);
label->setFixedWidth(40);
- label->setAlignment(AlignCenter);
+ label->tqsetAlignment(AlignCenter);
m_labels.push_back(label);
}
@@ -178,11 +178,11 @@ NameSetEditor::slotToggleInitialLabel()
else
index = 0;
- m_initialLabel->setText(TQString("%1").arg(index++));
+ m_initialLabel->setText(TQString("%1").tqarg(index++));
for (std::vector<TQLabel*>::iterator it( m_labels.begin() );
it != m_labels.end();
++it) {
- (*it)->setText(TQString("%1").arg(index++));
+ (*it)->setText(TQString("%1").tqarg(index++));
}
}
diff --git a/src/gui/studio/NameSetEditor.h b/src/gui/studio/NameSetEditor.h
index 8fd33ef..cef94a2 100644
--- a/src/gui/studio/NameSetEditor.h
+++ b/src/gui/studio/NameSetEditor.h
@@ -47,9 +47,10 @@ namespace Rosegarden
class BankEditorDialog;
-class NameSetEditor : public QVGroupBox
+class NameSetEditor : public TQVGroupBox
{
Q_OBJECT
+ TQ_OBJECT
public:
virtual void clearAll() = 0;
@@ -64,7 +65,7 @@ public slots:
protected:
NameSetEditor(BankEditorDialog *bankEditor,
TQString title,
- TQWidget *parent,
+ TQWidget *tqparent,
const char *name,
TQString headingPrefix = "",
bool showEntryButtons = false);
diff --git a/src/gui/studio/RemapInstrumentDialog.cpp b/src/gui/studio/RemapInstrumentDialog.cpp
index a957650..b1aff98 100644
--- a/src/gui/studio/RemapInstrumentDialog.cpp
+++ b/src/gui/studio/RemapInstrumentDialog.cpp
@@ -50,9 +50,9 @@
namespace Rosegarden
{
-RemapInstrumentDialog::RemapInstrumentDialog(TQWidget *parent,
+RemapInstrumentDialog::RemapInstrumentDialog(TQWidget *tqparent,
RosegardenGUIDoc *doc):
- KDialogBase(parent, "", true, i18n("Remap Instrument assigments..."),
+ KDialogBase(tqparent, "", true, i18n("Remap Instrument assigments..."),
Ok | Apply | Cancel),
m_doc(doc)
{
diff --git a/src/gui/studio/RemapInstrumentDialog.h b/src/gui/studio/RemapInstrumentDialog.h
index c0cae3a..d5999f8 100644
--- a/src/gui/studio/RemapInstrumentDialog.h
+++ b/src/gui/studio/RemapInstrumentDialog.h
@@ -48,8 +48,9 @@ class MultiViewCommandHistory;
class RemapInstrumentDialog : public KDialogBase
{
Q_OBJECT
+ TQ_OBJECT
public:
- RemapInstrumentDialog(TQWidget *parent,
+ RemapInstrumentDialog(TQWidget *tqparent,
RosegardenGUIDoc *doc);
void populateCombo(int id);
diff --git a/src/gui/studio/StudioControl.cpp b/src/gui/studio/StudioControl.cpp
index 6a4d643..04a838c 100644
--- a/src/gui/studio/StudioControl.cpp
+++ b/src/gui/studio/StudioControl.cpp
@@ -60,7 +60,7 @@ streamOut << (int)type;
if (!rgapp->sequencerCall("createMappedObject(int)",
replyType, replyData, data))
{
- SEQMAN_DEBUG << "createStudioObject - "
+ SETQMAN_DEBUG << "createStudioObject - "
<< "failed to contact Rosegarden sequencer"
<< endl;
} else
@@ -87,7 +87,7 @@ StudioControl::destroyStudioObject(MappedObjectId id)
if (!rgapp->sequencerCall("destroyMappedObject(int)",
replyType, replyData, data)) {
- SEQMAN_DEBUG << "destroyStudioObject - "
+ SETQMAN_DEBUG << "destroyStudioObject - "
<< "failed to contact Rosegarden sequencer"
<< endl;
} else {
@@ -119,7 +119,7 @@ StudioControl::getStudioObjectProperty(MappedObjectId id,
if (!rgapp->sequencerCall("getPropertyList(int, TQString)",
replyType, replyData, data)) {
- SEQMAN_DEBUG << "getStudioObjectProperty - "
+ SETQMAN_DEBUG << "getStudioObjectProperty - "
<< "failed to contact Rosegarden sequencer"
<< endl;
} else {
@@ -224,7 +224,7 @@ StudioControl::getStudioObjectByType(MappedObject::MappedObjectType type)
if (!rgapp->sequencerCall("getMappedObjectId(int)",
replyType, replyData, data)) {
- SEQMAN_DEBUG << "getStudioObjectByType - "
+ SETQMAN_DEBUG << "getStudioObjectByType - "
<< "failed to contact Rosegarden sequencer"
<< endl;
} else {
@@ -271,7 +271,7 @@ StudioControl::getStudioPluginPort(MappedObjectId pluginId,
if (!rgapp->sequencerCall("getMappedPort(int, unsigned long int)",
replyType, replyData, data)) {
- SEQMAN_DEBUG << "getStudioPluginPort - "
+ SETQMAN_DEBUG << "getStudioPluginPort - "
<< "failed to contact Rosegarden sequencer"
<< endl;
} else {
@@ -293,7 +293,7 @@ StudioControl::getPluginInformation()
if (!rgapp->sequencerCall("getPluginInformation()",
replyType, replyData, data)) {
- SEQMAN_DEBUG << "getPluginInformation - "
+ SETQMAN_DEBUG << "getPluginInformation - "
<< "failed to contact Rosegarden sequencer"
<< endl;
} else {
@@ -304,7 +304,7 @@ StudioControl::getPluginInformation()
return list;
}
-QString
+TQString
StudioControl::getPluginProgram(MappedObjectId id, int bank, int program)
{
TQByteArray data;
@@ -320,7 +320,7 @@ StudioControl::getPluginProgram(MappedObjectId id, int bank, int program)
if (!rgapp->sequencerCall("getPluginProgram(int, int, int)",
replyType, replyData, data)) {
- SEQMAN_DEBUG << "getPluginProgram - "
+ SETQMAN_DEBUG << "getPluginProgram - "
<< "failed to contact Rosegarden sequencer"
<< endl;
} else {
@@ -346,7 +346,7 @@ StudioControl::getPluginProgram(MappedObjectId id, TQString name)
if (!rgapp->sequencerCall("getPluginProgram(int, TQString)",
replyType, replyData, data)) {
- SEQMAN_DEBUG << "getPluginProgram - "
+ SETQMAN_DEBUG << "getPluginProgram - "
<< "failed to contact Rosegarden sequencer"
<< endl;
} else {
@@ -370,7 +370,7 @@ StudioControl::connectStudioObjects(MappedObjectId id1,
streamOut << (int)id2;
if (!rgapp->sequencerSend("connectMappedObjects(int, int)", data)) {
- SEQMAN_DEBUG << "connectStudioObjects - "
+ SETQMAN_DEBUG << "connectStudioObjects - "
<< "failed to contact Rosegarden sequencer"
<< endl;
}
@@ -391,7 +391,7 @@ StudioControl::disconnectStudioObjects(MappedObjectId id1,
streamOut << (int)id2;
if (!rgapp->sequencerSend("disconnectMappedObjects(int, int)", data)) {
- SEQMAN_DEBUG << "disconnectStudioObjects - "
+ SETQMAN_DEBUG << "disconnectStudioObjects - "
<< "failed to contact Rosegarden sequencer"
<< endl;
}
@@ -410,7 +410,7 @@ StudioControl::disconnectStudioObject(MappedObjectId id)
streamOut << (int)id;
if (!rgapp->sequencerSend("disconnectMappedObject(int)", data)) {
- SEQMAN_DEBUG << "disconnectStudioObject - "
+ SETQMAN_DEBUG << "disconnectStudioObject - "
<< "failed to contact Rosegarden sequencer"
<< endl;
}
diff --git a/src/gui/studio/SynthPluginManagerDialog.cpp b/src/gui/studio/SynthPluginManagerDialog.cpp
index 037fa3a..9530fad 100644
--- a/src/gui/studio/SynthPluginManagerDialog.cpp
+++ b/src/gui/studio/SynthPluginManagerDialog.cpp
@@ -54,13 +54,13 @@
namespace Rosegarden
{
-SynthPluginManagerDialog::SynthPluginManagerDialog(TQWidget *parent,
+SynthPluginManagerDialog::SynthPluginManagerDialog(TQWidget *tqparent,
RosegardenGUIDoc *doc
#ifdef HAVE_LIBLO
, AudioPluginOSCGUIManager *guiManager
#endif
) :
- KMainWindow(parent, "synthpluginmanagerdialog"),
+ KMainWindow(tqparent, "synthpluginmanagerdialog"),
m_document(doc),
m_studio(&doc->getStudio()),
m_pluginManager(doc->getPluginManager())
@@ -75,7 +75,7 @@ SynthPluginManagerDialog::SynthPluginManagerDialog(TQWidget *parent,
TQVBoxLayout *mainLayout = new TQVBoxLayout(mainBox, 10, 10);
- TQGroupBox *groupBox = new TQGroupBox(1, Horizontal, i18n("Synth plugins"), mainBox);
+ TQGroupBox *groupBox = new TQGroupBox(1, Qt::Horizontal, i18n("Synth plugins"), mainBox);
mainLayout->addWidget(groupBox);
TQFrame *pluginFrame = new TQFrame(groupBox);
@@ -105,7 +105,7 @@ SynthPluginManagerDialog::SynthPluginManagerDialog(TQWidget *parent,
// pluginLayout->addWidget(new TQLabel(instrument->getPresentationName().c_str(),
// pluginFrame), i, 0);
- pluginLayout->addWidget(new TQLabel(TQString("%1").arg(i + 1),
+ pluginLayout->addWidget(new TQLabel(TQString("%1").tqarg(i + 1),
pluginFrame), i, 0);
AudioPluginInstance *plugin = instrument->getPlugin
@@ -161,17 +161,17 @@ SynthPluginManagerDialog::SynthPluginManagerDialog(TQWidget *parent,
TQFrame* btnBox = new TQFrame(mainBox);
- btnBox->setSizePolicy(
+ btnBox->tqsetSizePolicy(
TQSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Fixed));
TQPushButton *closeButton = new TQPushButton(i18n("Close"), btnBox);
- TQHBoxLayout* layout = new TQHBoxLayout(btnBox, 0, 10);
- layout->addStretch(10);
- layout->addWidget(closeButton);
- layout->addSpacing(5);
+ TQHBoxLayout* tqlayout = new TQHBoxLayout(btnBox, 0, 10);
+ tqlayout->addStretch(10);
+ tqlayout->addWidget(closeButton);
+ tqlayout->addSpacing(5);
- KAction* close = KStdAction::close(this,
+ KAction* close = KStdAction::close(TQT_TQOBJECT(this),
TQT_SLOT(slotClose()),
actionCollection());
@@ -233,12 +233,12 @@ SynthPluginManagerDialog::SynthPluginManagerDialog(TQWidget *parent,
void
SynthPluginManagerDialog::slotGUIButtonClicked()
{
- const TQObject *s = sender();
+ const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
int instrumentNo = -1;
for (unsigned int i = 0; i < m_guiButtons.size(); ++i) {
- if (s == m_guiButtons[i])
+ if (TQT_BASE_OBJECT_CONST(s) == TQT_BASE_OBJECT(m_guiButtons[i]))
instrumentNo = i;
}
@@ -255,12 +255,12 @@ SynthPluginManagerDialog::SynthPluginManagerDialog(TQWidget *parent,
void
SynthPluginManagerDialog::slotControlsButtonClicked()
{
- const TQObject *s = sender();
+ const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
int instrumentNo = -1;
for (unsigned int i = 0; i < m_controlsButtons.size(); ++i) {
- if (s == m_controlsButtons[i])
+ if (TQT_BASE_OBJECT_CONST(s) == TQT_BASE_OBJECT(m_controlsButtons[i]))
instrumentNo = i;
}
@@ -277,7 +277,7 @@ SynthPluginManagerDialog::SynthPluginManagerDialog(TQWidget *parent,
void
SynthPluginManagerDialog::slotPluginChanged(int index)
{
- const TQObject *s = sender();
+ const TQObject *s = TQT_TQOBJECT_CONST(const_cast<const TQT_BASE_OBJECT_NAME*>(sender()));
RG_DEBUG << "SynthPluginManagerDialog::slotPluginChanged(" << index
<< ")" << endl;
@@ -285,7 +285,7 @@ SynthPluginManagerDialog::SynthPluginManagerDialog(TQWidget *parent,
int instrumentNo = -1;
for (unsigned int i = 0; i < m_synthCombos.size(); ++i) {
- if (s == m_synthCombos[i])
+ if (TQT_BASE_OBJECT_CONST(s) == TQT_BASE_OBJECT(m_synthCombos[i]))
instrumentNo = i;
}
@@ -316,7 +316,7 @@ SynthPluginManagerDialog::SynthPluginManagerDialog(TQWidget *parent,
if (plugin) {
RG_DEBUG << "plugin is " << plugin->getIdentifier() << endl;
- pluginInstance->setIdentifier(plugin->getIdentifier().data());
+ pluginInstance->setIdentifier(plugin->getIdentifier().ascii());
// set ports to defaults
diff --git a/src/gui/studio/SynthPluginManagerDialog.h b/src/gui/studio/SynthPluginManagerDialog.h
index f58c07c..d637e7a 100644
--- a/src/gui/studio/SynthPluginManagerDialog.h
+++ b/src/gui/studio/SynthPluginManagerDialog.h
@@ -49,9 +49,10 @@ class AudioPluginManager;
class SynthPluginManagerDialog : public KMainWindow
{
Q_OBJECT
+ TQ_OBJECT
public:
- SynthPluginManagerDialog(TQWidget *parent,
+ SynthPluginManagerDialog(TQWidget *tqparent,
RosegardenGUIDoc *doc
#ifdef HAVE_LIBLO
, AudioPluginOSCGUIManager *guiManager
diff --git a/src/gui/studio/TimerCallbackAssistant.cpp b/src/gui/studio/TimerCallbackAssistant.cpp
index 7b2bc76..23534d3 100644
--- a/src/gui/studio/TimerCallbackAssistant.cpp
+++ b/src/gui/studio/TimerCallbackAssistant.cpp
@@ -44,7 +44,7 @@ TimerCallbackAssistant::TimerCallbackAssistant(int ms, void (*callback)(void *da
TimerCallbackAssistant::~TimerCallbackAssistant()
{
- // nothing -- the TQTimer is deleted automatically by its parent TQObject (me)
+ // nothing -- the TQTimer is deleted automatically by its tqparent TQObject (me)
}
void
diff --git a/src/gui/studio/TimerCallbackAssistant.h b/src/gui/studio/TimerCallbackAssistant.h
index 836db90..3048f20 100644
--- a/src/gui/studio/TimerCallbackAssistant.h
+++ b/src/gui/studio/TimerCallbackAssistant.h
@@ -39,9 +39,10 @@ namespace Rosegarden
AudioPluginOSCGUI cannot be a TQObject because it's only
conditionally compiled. */
-class TimerCallbackAssistant : public QObject
+class TimerCallbackAssistant : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
TimerCallbackAssistant(int ms, void (*callback)(void *data), void *data);
diff --git a/src/gui/studio/BankEditorDialog.cpp b/src/gui/studio/BankEditorDialog.cpp
index 5c5c3d2..6103652 100644
--- a/src/gui/studio/BankEditorDialog.cpp
+++ b/src/gui/studio/BankEditorDialog.cpp
@@ -78,10 +78,10 @@
namespace Rosegarden
{
-BankEditorDialog::BankEditorDialog(TQWidget *parent,
+BankEditorDialog::BankEditorDialog(TQWidget *tqparent,
RosegardenGUIDoc *doc,
DeviceId defaultDevice):
- KMainWindow(parent, "bankeditordialog"),
+ KMainWindow(tqparent, "bankeditordialog"),
m_studio(&doc->getStudio()),
m_doc(doc),
m_copyBank(Device::NO_DEVICE, -1),
@@ -100,20 +100,20 @@ BankEditorDialog::BankEditorDialog(TQWidget *parent,
TQFrame* btnBox = new TQFrame(mainFrame);
- btnBox->setSizePolicy(TQSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Fixed));
+ btnBox->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Fixed));
- TQHBoxLayout* layout = new TQHBoxLayout(btnBox, 4, 10);
+ TQHBoxLayout* tqlayout = new TQHBoxLayout(btnBox, 4, 10);
m_closeButton = new TQPushButton(btnBox);
m_applyButton = new TQPushButton(i18n("Apply"), btnBox);
m_resetButton = new TQPushButton(i18n("Reset"), btnBox);
- layout->addStretch(10);
- layout->addWidget(m_applyButton);
- layout->addWidget(m_resetButton);
- layout->addSpacing(15);
- layout->addWidget(m_closeButton);
- layout->addSpacing(5);
+ tqlayout->addStretch(10);
+ tqlayout->addWidget(m_applyButton);
+ tqlayout->addWidget(m_resetButton);
+ tqlayout->addSpacing(15);
+ tqlayout->addWidget(m_closeButton);
+ tqlayout->addSpacing(5);
connect(m_applyButton, TQT_SIGNAL(clicked()),
this, TQT_SLOT(slotApply()));
@@ -206,8 +206,8 @@ BankEditorDialog::BankEditorDialog(TQWidget *parent,
vboxLayout->addWidget(m_keyMappingEditor);
m_keyMappingEditor->hide();
- m_programEditor->setSizePolicy(TQSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Preferred));
- m_keyMappingEditor->setSizePolicy(TQSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Preferred));
+ m_programEditor->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Preferred));
+ m_keyMappingEditor->tqsetSizePolicy(TQSizePolicy(TQSizePolicy::Minimum, TQSizePolicy::Preferred));
m_optionBox = new TQVGroupBox(i18n("Options"), vbox);
vboxLayout->addWidget(m_optionBox);
@@ -303,14 +303,14 @@ BankEditorDialog::~BankEditorDialog()
void
BankEditorDialog::setupActions()
{
- KAction* close = KStdAction::close (this, TQT_SLOT(slotFileClose()), actionCollection());
+ KAction* close = KStdAction::close (TQT_TQOBJECT(this), TQT_SLOT(slotFileClose()), actionCollection());
m_closeButton->setText(close->text());
connect(m_closeButton, TQT_SIGNAL(clicked()),
- this, TQT_SLOT(slotFileClose()));
+ TQT_TQOBJECT(this), TQT_SLOT(slotFileClose()));
- KStdAction::copy (this, TQT_SLOT(slotEditCopy()), actionCollection());
- KStdAction::paste (this, TQT_SLOT(slotEditPaste()), actionCollection());
+ KStdAction::copy (TQT_TQOBJECT(this), TQT_SLOT(slotEditCopy()), actionCollection());
+ KStdAction::paste (TQT_TQOBJECT(this), TQT_SLOT(slotEditPaste()), actionCollection());
// some adjustments
@@ -593,7 +593,7 @@ BankEditorDialog::updateDeviceItem(MidiDeviceListViewItem* deviceItem)
// delete banks which are no longer present
//
- std::vector<TQListViewItem*> childrenToDelete;
+ std::vector<TQListViewItem*> tqchildrenToDelete;
TQListViewItem* child = deviceItem->firstChild();
@@ -603,7 +603,7 @@ BankEditorDialog::updateDeviceItem(MidiDeviceListViewItem* deviceItem)
dynamic_cast<MidiBankListViewItem *>(child);
if (bankItem) {
if (bankItem->getBank() >= int(banks.size()))
- childrenToDelete.push_back(child);
+ tqchildrenToDelete.push_back(child);
else { // update the banks MSB/LSB which might have changed
bankItem->setPercussion(banks[bankItem->getBank()].isPercussion());
bankItem->setMSB(banks[bankItem->getBank()].getMSB());
@@ -615,15 +615,15 @@ BankEditorDialog::updateDeviceItem(MidiDeviceListViewItem* deviceItem)
dynamic_cast<MidiKeyMapListViewItem *>(child);
if (keyItem) {
if (!midiDevice->getKeyMappingByName(qstrtostr(keyItem->getName()))) {
- childrenToDelete.push_back(child);
+ tqchildrenToDelete.push_back(child);
}
}
child = child->nextSibling();
}
- for (unsigned int i = 0; i < childrenToDelete.size(); ++i)
- delete childrenToDelete[i];
+ for (unsigned int i = 0; i < tqchildrenToDelete.size(); ++i)
+ delete tqchildrenToDelete[i];
}
bool
@@ -968,15 +968,15 @@ BankEditorDialog::getParentDeviceItem(TQListViewItem* item)
return 0;
if (dynamic_cast<MidiBankListViewItem*>(item))
- // go up to the parent device item
- item = item->parent();
+ // go up to the tqparent device item
+ item = item->tqparent();
if (dynamic_cast<MidiKeyMapListViewItem*>(item))
- // go up to the parent device item
- item = item->parent();
+ // go up to the tqparent device item
+ item = item->tqparent();
if (!item) {
- RG_DEBUG << "BankEditorDialog::getParentDeviceItem : missing parent device item for bank item - this SHOULD NOT HAPPEN" << endl;
+ RG_DEBUG << "BankEditorDialog::getParentDeviceItem : missing tqparent device item for bank item - this SHOULD NOT HAPPEN" << endl;
return 0;
}
@@ -1045,7 +1045,7 @@ BankEditorDialog::slotAddKeyMapping()
if (n == 1)
name = i18n("<new mapping>");
else
- name = i18n("<new mapping %1>").arg(n);
+ name = i18n("<new mapping %1>").tqarg(n);
}
MidiKeyMapping newKeyMapping(qstrtostr(name));